@@ -2,4 +2,6 @@ from .find import Finder
 # from .scholar import ScholarSearch
 from .acm import ACMSearch
 from .ieee import IEEESearch
-from .search import Search
\ No newline at end of file
+from .search import Search
+from .sciencedirect import ScienceDirectSearch
+from .springer import SpringerLinkSearch
\ No newline at end of file
